==> pdepend_2.12.1.orig.tar.xz: pdepend-2.12.1/src/main/php/PDepend/Util/MathUtil.php <==
<?php
/**
 * This file is part of PDepend.
 *
 * PHP Version 5
 *
 * Copyright (c) 2008-2017 Manuel Pichler <mapi@pdepend.org>.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   * Neither the name of Manuel Pichler nor the names of his
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * @copyright 2008-2017 Manuel Pichler. All rights reserved.
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 */

namespace PDepend\Util;

/**
 * This is a simply utility class that will perform mathematical operations with
 * bcmath when the extension exists, otherwise it will use default math operations.
 *
 * @copyright 2008-2017 Manuel Pichler. All rights reserved.
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 */
final class MathUtil
{
    /**
     * This method will multiply the two given operands with the bcmath extension
     * when available, otherwise it will use the default mathematical operations.
     *
     * @param string $left  The left arithmetic operand.
     * @param string $right The right arithmetic operand.
     *
     * @return string
     */
    public static function mul($left, $right)
    {
        if (function_exists('bcmul')) {
            return bcmul($left, $right);
        }
        return (string) ((int) $left * (int) $right);
    }

    /**
     * This method will add the two given operands with the bcmath extension
     * when available, otherwise it will use the default mathematical operations.
     *
     * @param string $left  The left arithmetic operand.
     * @param string $right The right arithmetic operand.
     *
     * @return string
     */
    public static function add($left, $right)
    {
        if (function_exists('bcadd')) {
            return bcadd($left, $right);
        }
        return (string) ((int) $left + (int) $right);
    }
}

==> pdepend_2.16.2.orig.tar.xz: pdepend-2.16.2/src/main/php/PDepend/Util/MathUtil.php <==
<?php
/**
 * This file is part of PDepend.
 *
 * PHP Version 5
 *
 * Copyright (c) 2008-2017 Manuel Pichler <mapi@pdepend.org>.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   * Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 *
 *   * Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 *
 *   * Neither the name of Manuel Pichler nor the names of his
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * @copyright 2008-2017 Manuel Pichler. All rights reserved.
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 */

namespace PDepend\Util;

/**
 * This is a simply utility class that will perform mathematical operations with
 * bcmath when the extension exists, otherwise it will use default math operations.
 *
 * @copyright 2008-2017 Manuel Pichler. All rights reserved.
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 */
final class MathUtil
{
    /**
     * This method will multiply the two given operands with the bcmath extension
     * when available, otherwise it will use the default mathematical operations.
     *
     * @param numeric-string $left  The left arithmetic operand.
     * @param numeric-string $right The right arithmetic operand.
     *
     * @return numeric-string
     */
    public static function mul($left, $right)
    {
        if (function_exists('bcmul')) {
            return bcmul($left, $right);
        }
        return (string) ((int) $left * (int) $right);
    }

    /**
     * This method will add the two given operands with the bcmath extension
     * when available, otherwise it will use the default mathematical operations.
     *
     * @param string $left  The left arithmetic operand.
     * @param string $right The right arithmetic operand.
     *
     * @return numeric-string
     */
    public static function add($left, $right)
    {
        if (function_exists('bcadd')) {
            return bcadd($left, $right);
        }
        return (string) ((int) $left + (int) $right);
    }
}
